Enum Class LoggerField
- All Implemented Interfaces:
Serializable, Comparable<LoggerField>, Constable, KeyAccessor<String>, TypeAccessor, ColumnAccessor
public enum LoggerField
extends Enum<LoggerField>
implements ColumnAccessor, KeyAccessor<String>, TypeAccessor
Defines default logger
Header.-
Nested Class Summary
Nested classes/interfaces inherited from class Enum
Enum.EnumDesc<E>Nested classes/interfaces inherited from interface ColumnAccessor
ColumnAccessor.ColumnMutator<T>, ColumnAccessor.ColumnProperty<T>Nested classes/interfaces inherited from interface KeyAccessor
KeyAccessor.KeyBuilder<K,B>, KeyAccessor.KeyMutator<K>, KeyAccessor.KeyProperty<K> Nested classes/interfaces inherited from interface TypeAccessor
TypeAccessor.TypeBuilder<T,B>, TypeAccessor.TypeMutator<T>, TypeAccessor.TypeProperty<T> -
Enum Constant Summary
Enum Constants -
Method Summary
Modifier and TypeMethodDescriptionstatic Column<?> Gets a predefined column by key (name).Column<?> getKey()Class<?> getType()static LoggerFieldtoExceptionLoggerField(PrintStackTrace aPrintStackTrace) To exception logger field.static LoggerFieldReturns the enum constant of this class with the specified name.static LoggerField[]values()Returns an array containing the constants of this enum class, in the order they are declared.
-
Enum Constant Details
-
LOG_LINE_NUMBER
-
LOG_PRIORITY
-
LOG_DATE
-
LOG_THREAD_NAME
-
LOG_SESSION_ID
-
LOG_REQUEST_ID
-
LOG_MESSAGE
-
LOG_NONE_STACKTRRACE_EXCEPTION
-
LOG_COMPACT_STACKTRACE_EXCEPTION
-
LOG_EXPLODED_STACKTRACE_EXCEPTION
-
LOG_FULLY_QUALIFIED_CLASS_NAME
-
LOG_METHODE_NAME
-
LOG_CLASS_LINE_NUMBER
-
-
Method Details
-
values
Returns an array containing the constants of this enum class, in the order they are declared.- Returns:
- an array containing the constants of this enum class, in the order they are declared
-
valueOf
Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum class has no constant with the specified nameNullPointerException- if the argument is null
-
getColumn
- Specified by:
getColumnin interfaceColumnAccessor
-
getKey
- Specified by:
getKeyin interfaceKeyAccessor<String>
-
getType
- Specified by:
getTypein interfaceTypeAccessor
-
toExceptionLoggerField
To exception logger field.- Parameters:
aPrintStackTrace- the print stack trace- Returns:
- the logger field
-
fromKey
-