Class MethodNameColumn

java.lang.Object
org.refcodes.tabular.AbstractColumn<String>
org.refcodes.logger.MethodNameColumn
All Implemented Interfaces:
Cloneable, KeyAccessor<String>, TypeAccessor<String>, Column<String>

public class MethodNameColumn extends AbstractColumn<String>
Implementation of a Column for working with String instances with the semantics of a method name, being Cloneable.