Interface QueryLogger<T>

Type Parameters:
T - The type of the Record instances managed by the Logger.
All Superinterfaces:
LogDecorator, Logger<T>
All Known Subinterfaces:
TrimLogger<T>
All Known Implementing Classes:
PartedQueryLogger, PartedTrimLogger, QueryLoggerDispatcher, TrimLoggerDispatcher

public interface QueryLogger<T> extends Logger<T>
The QueryLogger extends the Logger; providing additional functionality for querying once logged data Records by specifying query Criteria or other query restrictions.
  • Method Details

    • findLogs

      Records<T> findLogs()
      Retrieves all available Record instances being logged.
      Returns:
      A Records instance containing all available Record instances being logged.
    • findLogs

      Records<T> findLogs(int aLimit)
      Retrieves all available Record instances being logged matching the given criteria and restrictions.
      Parameters:
      aLimit - The maximum Record instances contained in the returned Records instance; there may be more Record instances which are not contained in the Records instance in case the Records instance's size is that of the specified limit.
      Returns:
      A Records instance containing all available Record instances being logged matching the given criteria and restrictions.
    • findLogs

      Records<T> findLogs(Header<T> aHeader, int aLimit)
      Retrieves all available Record instances being logged matching the given criteria and restrictions.
      Parameters:
      aHeader - The Header used to restrict the "columns" (key/value entries) in the retrieved Record instances (provided by the Records instance).
      aLimit - The maximum Record instances contained in the returned Records instance; there may be more Record instances which are not contained in the Records instance in case the Records instance's size is that of the specified limit.
      Returns:
      A Records instance containing all available Record instances being logged matching the given criteria and restrictions.
    • findLogs

      Records<T> findLogs(Criteria aCriteria) throws BadCriteriaException
      Retrieves all available Record instances being logged matching the given criteria and restrictions.
      Parameters:
      aCriteria - The Criteria to be applied to the Record instances
      Returns:
      A Records instance containing all available Record instances being logged matching the given criteria and restrictions.
      Throws:
      BadCriteriaException - thrown in case of problems related to some Criteria.
    • findLogs

      Records<T> findLogs(Criteria aCriteria, int aLimit) throws BadCriteriaException
      Retrieves all available Record instances being logged matching the given criteria and restrictions.
      Parameters:
      aCriteria - The Criteria to be applied to the Record instances
      aLimit - The maximum Record instances contained in the returned Records instance; there may be more Record instances which are not contained in the Records instance in case the Records instance's size is that of the specified limit.
      Returns:
      A Records instance containing all available Record instances being logged matching the given criteria and restrictions.
      Throws:
      BadCriteriaException - thrown in case of problems related to some Criteria.
    • findLogs

      Records<T> findLogs(Criteria aCriteria, Header<T> aHeader) throws BadCriteriaException
      Retrieves all available Record instances being logged matching the given criteria and restrictions.
      Parameters:
      aCriteria - The Criteria to be applied to the Record instances
      aHeader - The Header used to restrict the "columns" (key/value entries) in the retrieved Record instances (provided by the Records instance).
      Returns:
      A Records instance containing all available Record instances being logged matching the given criteria and restrictions.
      Throws:
      BadCriteriaException - thrown in case of problems related to some Criteria.
    • findLogs

      Records<T> findLogs(Criteria aCriteria, Header<T> aHeader, int aLimit) throws BadCriteriaException
      Retrieves all available Record instances being logged matching the given criteria and restrictions.
      Parameters:
      aCriteria - The Criteria to be applied to the Record instances
      aHeader - The Header used to restrict the "columns" (key/value entries) in the retrieved Record instances (provided by the Records instance).
      aLimit - The maximum Record instances contained in the returned Records instance; there may be more Record instances which are not contained in the Records instance in case the Records instance's size is that of the specified limit.
      Returns:
      A Records instance containing all available Record instances being logged matching the given criteria and restrictions.
      Throws:
      BadCriteriaException - thrown in case of problems related to some Criteria.