Class QueryLoggerDispatcher<T>

java.lang.Object
org.refcodes.logger.QueryLoggerDispatcher<T>
Type Parameters:
T - The type of the Record instances managed by the Logger.
All Implemented Interfaces:
Flushable, Closable, ComponentComposite, Decomposable, Destroyable, Flushable, Initializable, LifecycleComponent, LinkComponent, Openable, Pausable, Resumable, Startable, Stoppable, LogDecorator, Logger<T>, QueryLogger<T>, Disposable, Resetable

public class QueryLoggerDispatcher<T> extends Object implements ComponentComposite
The QueryLoggerDispatcher is a ready to use implementation of a composite QueryLogger extending the AbstractQueryLoggerDispatcher.
See Also: