Interface RuntimeLoggerFactory

All Superinterfaces:
Factory<RuntimeLogger>, LookupFactory<RuntimeLogger, String>, TypeAccessor<RuntimeLogger>, TypeFactory<RuntimeLogger>
All Known Implementing Classes:
DefaultRuntimeLoggerFactory, RuntimeLoggerFactorySingleton

public interface RuntimeLoggerFactory extends TypeFactory<RuntimeLogger>, LookupFactory<RuntimeLogger, String>
A RuntimeLoggerFactory defines the methods required to factor RuntimeLogger instances. You might also provide a static method with the following signature in order to provide singleton functionality and avoid to create too many unnecessary RuntimeLogger instances:

public RuntimeLogger getInstance() { ... }