Class RuntimeLoggerSingleton
- All Implemented Interfaces:
LogDecorator, LogPriorityAccessor, MessageLogger<LogPriority>, RuntimeLogger, NameAccessor
This RuntimeLoggerSingleton provides a RuntimeLogger
singleton configured by a "runtimelogger-config.xml" file find
in one of the several locations relative to your application's base
directory: The applications base directory (where your JAR or your classes
reside) is taken and a list of directories (as defined in the
Folders.CONFIG_DIRS) relative to this base directory is generated :
The actual directories being looked at (in case them exist) are as follows,
relative to your applications base directory:
- ../config"
- ../etc"
- ../settings"
- ../.config"
- ../settings"
- ."
- ./config"
- ./etc"
- ./settings"
- ./.config"
- ./settings"
In case you pass a JVM argument via "-Dconfig.dir=path_to_your_config_dir"
(where path_to_your_config_dir stands for the path to the directory where you
placed configuration files such as the
"runtimelogger-config.xml"" file), then your
path_to_your_config_dir is placed first in the list of configuration
directories to look at (in case the directory exists).See
SystemProperty.CONFIG_DIR
-
Nested Class Summary
Nested classes/interfaces inherited from interface LogPriorityAccessor
LogPriorityAccessor.LogPriorityMutator, LogPriorityAccessor.LogPriorityPropertyNested classes/interfaces inherited from interface NameAccessor
NameAccessor.NameBuilder<B>, NameAccessor.NameMutator, NameAccessor.NameProperty -
Field Summary
Fields inherited from interface RuntimeLogger
ROOT_LOGGER_ELEMENT_PATH, RUNTIME_LOGGER_CONFIG -
Constructor Summary
ConstructorsModifierConstructorDescriptionprotectedRuntimeLoggerSingleton(RuntimeLogger aRuntimeLogger) Instantiates a new runtime logger singleton. -
Method Summary
Modifier and TypeMethodDescriptionvoidLogs a log aMessage with log priorityLogPriority.ALERT.voidLogs a log aMessage with log priorityLogPriority.ALERT.voidLogs a log aMessage with log priorityLogPriority.ALERT.voidLogs a log aMessage with log priorityLogPriority.ALERT.voidLogs a log aMessage with log priorityLogPriority.CRITICAL.voidLogs a log aMessage with log priorityLogPriority.CRITICAL.voidLogs a log aMessage with log priorityLogPriority.CRITICAL.voidLogs a log aMessage with log priorityLogPriority.CRITICAL.voidLogs a log aMessage with log priorityLogPriority.DEBUG.voidLogs a log aMessage with log priorityLogPriority.DEBUG.voidLogs a log aMessage with log priorityLogPriority.ERROR.voidLogs a log aMessage with log priorityLogPriority.ERROR.voidLogs a log aMessage with log priorityLogPriority.ERROR.voidLogs a log aMessage with log priorityLogPriority.ERROR.static RuntimeLoggerReturns the singleton's instance as fabricated by thisRuntimeLoggerSingleton.Retrieves theLogPriorityfrom theLogPriorityAccessor.getName()voidLogs a log aMessage with log priorityLogPriority.INFO.voidLogs a log aMessage with log priorityLogPriority.INFO.booleanisLog(LogPriority aPriority) Determines whether theRuntimeLoggeris being configured to log messages of the accordingLogPriority.booleanDetermines whether theRuntimeLoggeris being configured to log fatal messages (LogPriority.ALERT).booleanDetermines whether theRuntimeLoggeris being configured to log fatal messages (LogPriority.CRITICAL).booleanDetermines whether theRuntimeLoggeris being configured to log debug messages (LogPriority.DEBUG).booleanDetermines whether theRuntimeLoggeris being configured to log errors (LogPriority.ERROR).booleanDetermines whether theRuntimeLoggeris being configured to log infos (LogPriority.INFO).booleanDetermines whether theRuntimeLoggeris being configured to log notices (LogPriority.NOTICE).booleanDetermines whether theRuntimeLoggeris being configured to log fatal messages (LogPriority.PANIC).booleanDetermines whether theRuntimeLoggeris being configured to log comments (LogPriority.TRACE).booleanDetermines whether theRuntimeLoggeris being configured to log warnings (LogPriority.WARN).voidlog(LogPriority aMarker, String aMessage) Creates a new log aMessage.voidlog(LogPriority aMarker, String aMessage, Object... aArguments) Creates a new log aMessage.voidlog(LogPriority aPriority, String aMessage, Throwable aThrowable) Creates a new log aMessage.voidlog(LogPriority aPriority, String aMessage, Throwable aThrowable, Object... aArguments) Creates a new log aMessage.voidLogs a log aMessage with log priorityLogPriority.NOTICE.voidLogs a log aMessage with log priorityLogPriority.NOTICE.voidLogs a log aMessage with log priorityLogPriority.PANIC.voidLogs a log aMessage with log priorityLogPriority.PANIC.voidLogs a log aMessage with log priorityLogPriority.PANIC.voidLogs a log aMessage with log priorityLogPriority.PANIC.voidLogs a log aMessage with log priorityLogPriority.TRACE.voidLogs a log aMessage with log priorityLogPriority.TRACE.voidLogs a log aMessage with log priorityLogPriority.WARN.voidLogs a log aMessage with log priorityLogPriority.WARN.voidLogs a log aMessage with log priorityLogPriority.WARN.voidLogs a log aMessage with log priorityLogPriority.WARN.Methods inherited from class Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, waitMethods inherited from interface LogDecorator
printHead, printSeparator, printTailMethods inherited from interface RuntimeLogger
log
-
Constructor Details
-
RuntimeLoggerSingleton
Instantiates a new runtime logger singleton.- Parameters:
aRuntimeLogger- the runtime logger
-
-
Method Details
-
getInstance
Returns the singleton's instance as fabricated by thisRuntimeLoggerSingleton.- Returns:
- The
RuntimeLoggersingleton's instance. - Throws:
LoggerInstantiationRuntimeException- Thrown in case instantiating aLogger(RuntimeLogger) failed
-
getName
- Specified by:
getNamein interfaceNameAccessor
-
getLogPriority
Retrieves theLogPriorityfrom theLogPriorityAccessor.- Specified by:
getLogPriorityin interfaceLogPriorityAccessor- Returns:
- The
LogPrioritystored by theLogPriorityAccessor.
-
log
Creates a new log aMessage.- Specified by:
login interfaceMessageLogger<LogPriority>- Parameters:
aMarker- The marker for the aMessage.aMessage- The aMessage to be logged.
-
log
Creates a new log aMessage.- Specified by:
login interfaceRuntimeLogger- Parameters:
aPriority- The level of the aMessage.aMessage- The aMessage to be logged.aThrowable- An exception that the aMessage should contain.
-
log
Creates a new log aMessage. The placeholders in the aMessageStringare being replaced by the provided arguments. Implementations of this interface are recommended to use Java'sMessageFormat's syntax, the placeholder being replaced by the first argument is identified by "{0}" (without the quotes), the second one by "{1}", the third one by "{3}" and so on: Given the aMessage to be "{0} + {1} = {2}" and the three argument be x, y and x + y, then "{0}" is replaced by the value of x, "{1}" is replaced by the value of y and "{2}" is replaced by the value of x + y.- Specified by:
login interfaceMessageLogger<LogPriority>- Parameters:
aMarker- The marker for the aMessage.aMessage- The aMessage to be logged.aArguments- The arguments used when replacing the placeholders.
-
log
Creates a new log aMessage. The placeholders in the aMessageStringare being replaced by the provided arguments. Implementations of this interface are recommended to use Java'sMessageFormat's syntax, the placeholder being replaced by the first argument is identified by "{0}" (without the quotes), the second one by "{1}", the third one by "{3}" and so on: Given the aMessage to be "{0} + {1} = {2}" and the three argument be x, y and x + y, then "{0}" is replaced by the value of x, "{1}" is replaced by the value of y and "{2}" is replaced by the value of x + y.- Specified by:
login interfaceRuntimeLogger- Parameters:
aPriority- The level of the aMessage.aMessage- The aMessage to be logged.aThrowable- An exception that the aMessage should contain.aArguments- The arguments used when replacing the placeholders.
-
isLog
Determines whether theRuntimeLoggeris being configured to log messages of the accordingLogPriority. This method is useful to prevent the generation of vast amounts of log aMessageStringobjects (and according processing) for the accordingLogPriorityin case them messages of thatLogPriorityare not logged at all.- Specified by:
isLogin interfaceRuntimeLogger- Parameters:
aPriority- TheLogPriorityto test whether theRuntimeLoggerdoes log messages of thatLogPriority.- Returns:
- True in case the
RuntimeLoggerdoes log messages of thatLogPriority.
-
trace
Logs a log aMessage with log priorityLogPriority.TRACE.- Specified by:
tracein interfaceRuntimeLogger- Parameters:
aMessage- The aMessage to be logged.
-
trace
Logs a log aMessage with log priorityLogPriority.TRACE. The placeholders in the aMessageStringare being replaced by the provided arguments. Implementations of this interface are recommended to use Java'sMessageFormat's syntax, the placeholder being replaced by the first argument is identified by "{0}" (without the quotes), the second one by "{1}", the third one by "{3}" and so on: Given the aMessage to be "{0} + {1} = {2}" and the three argument be x, y and x + y, then "{0}" is replaced by the value of x, "{1}" is replaced by the value of y and "{2}" is replaced by the value of x + y.- Specified by:
tracein interfaceRuntimeLogger- Parameters:
aMessage- The aMessage to be logged.aArguments- The arguments used when replacing the placeholders.
-
isLogTrace
public boolean isLogTrace()Determines whether theRuntimeLoggeris being configured to log comments (LogPriority.TRACE). This method is useful to prevent the generation of vast amounts of log aMessageStringobjects (and according processing) for the accordingLogPriorityin case them messages of thatLogPriorityare not logged at all.- Specified by:
isLogTracein interfaceRuntimeLogger- Returns:
- True in case comments are logged.
-
debug
Logs a log aMessage with log priorityLogPriority.DEBUG. "Info useful to developers for debugging the application, not useful during operations." See also http://en.wikipedia.org/wiki/Syslog- Specified by:
debugin interfaceRuntimeLogger- Parameters:
aMessage- The aMessage to be logged.
-
debug
Logs a log aMessage with log priorityLogPriority.DEBUG. "Info useful to developers for debugging the application, not useful during operations." The placeholders in the aMessageStringare being replaced by the provided arguments. Implementations of this interface are recommended to use Java'sMessageFormat's syntax, the placeholder being replaced by the first argument is identified by "{0}" (without the quotes), the second one by "{1}", the third one by "{3}" and so on: Given the aMessage to be "{0} + {1} = {2}" and the three argument be x, y and x + y, then "{0}" is replaced by the value of x, "{1}" is replaced by the value of y and "{2}" is replaced by the value of x + y. See also http://en.wikipedia.org/wiki/Syslog- Specified by:
debugin interfaceRuntimeLogger- Parameters:
aMessage- The aMessage to be logged.aArguments- The arguments used when replacing the placeholders.
-
isLogDebug
public boolean isLogDebug()Determines whether theRuntimeLoggeris being configured to log debug messages (LogPriority.DEBUG). This method is useful to prevent the generation of vast amounts of log aMessageStringobjects (and according processing) for the accordingLogPriorityin case them messages of thatLogPriorityare not logged at all.- Specified by:
isLogDebugin interfaceRuntimeLogger- Returns:
- True in case debug messages are logged.
-
info
Logs a log aMessage with log priorityLogPriority.INFO. "Additional information which might be useful for some stability period." See also http://en.wikipedia.org/wiki/Syslog- Specified by:
infoin interfaceRuntimeLogger- Parameters:
aMessage- The aMessage to be logged.
-
info
Logs a log aMessage with log priorityLogPriority.INFO. "Additional information which might be useful for some stability period." The placeholders in the aMessageStringare being replaced by the provided arguments. Implementations of this interface are recommended to use Java'sMessageFormat's syntax, the placeholder being replaced by the first argument is identified by "{0}" (without the quotes), the second one by "{1}", the third one by "{3}" and so on: Given the aMessage to be "{0} + {1} = {2}" and the three argument be x, y and x + y, then "{0}" is replaced by the value of x, "{1}" is replaced by the value of y and "{2}" is replaced by the value of x + y. See also http://en.wikipedia.org/wiki/Syslog- Specified by:
infoin interfaceRuntimeLogger- Parameters:
aMessage- The aMessage to be logged.aArguments- The arguments used when replacing the placeholders.
-
isLogInfo
public boolean isLogInfo()Determines whether theRuntimeLoggeris being configured to log infos (LogPriority.INFO). This method is useful to prevent the generation of vast amounts of log aMessageStringobjects (and according processing) for the accordingLogPriorityin case them messages of thatLogPriorityare not logged at all.- Specified by:
isLogInfoin interfaceRuntimeLogger- Returns:
- True in case infos are logged.
-
notice
Logs a log aMessage with log priorityLogPriority.NOTICE. "Events that are unusual but not error conditions - might be summarized in an email to developers or admins to spot potential problems - no immediate action required." See also http://en.wikipedia.org/wiki/Syslog- Specified by:
noticein interfaceRuntimeLogger- Parameters:
aMessage- The aMessage to be logged.
-
notice
Logs a log aMessage with log priorityLogPriority.NOTICE. "Events that are unusual but not error conditions - might be summarized in an email to developers or admins to spot potential problems - no immediate action required." The placeholders in the aMessageStringare being replaced by the provided arguments. Implementations of this interface are recommended to use Java'sMessageFormat's syntax, the placeholder being replaced by the first argument is identified by "{0}" (without the quotes), the second one by "{1}", the third one by "{3}" and so on: Given the aMessage to be "{0} + {1} = {2}" and the three argument be x, y and x + y, then "{0}" is replaced by the value of x, "{1}" is replaced by the value of y and "{2}" is replaced by the value of x + y. See also http://en.wikipedia.org/wiki/Syslog- Specified by:
noticein interfaceRuntimeLogger- Parameters:
aMessage- The aMessage to be logged.aArguments- The arguments used when replacing the placeholders.
-
isLogNotice
public boolean isLogNotice()Determines whether theRuntimeLoggeris being configured to log notices (LogPriority.NOTICE). This method is useful to prevent the generation of vast amounts of log aMessageStringobjects (and according processing) for the accordingLogPriorityin case them messages of thatLogPriorityare not logged at all.- Specified by:
isLogNoticein interfaceRuntimeLogger- Returns:
- True in case infos are logged.
-
warn
Logs a log aMessage with log priorityLogPriority.WARN. "Warning messages, not an error, but indication that an error will occur if action is not taken, e.g. file system 85% full - each item must be resolved within a given time." See also http://en.wikipedia.org/wiki/Syslog- Specified by:
warnin interfaceRuntimeLogger- Parameters:
aMessage- The aMessage to be logged.
-
warn
Logs a log aMessage with log priorityLogPriority.WARN. "Warning messages, not an error, but indication that an error will occur if action is not taken, e.g. file system 85% full - each item must be resolved within a given time." The placeholders in the aMessageStringare being replaced by the provided arguments. Implementations of this interface are recommended to use Java'sMessageFormat's syntax, the placeholder being replaced by the first argument is identified by "{0}" (without the quotes), the second one by "{1}", the third one by "{3}" and so on: Given the aMessage to be "{0} + {1} = {2}" and the three argument be x, y and x + y, then "{0}" is replaced by the value of x, "{1}" is replaced by the value of y and "{2}" is replaced by the value of x + y. See also http://en.wikipedia.org/wiki/Syslog- Specified by:
warnin interfaceRuntimeLogger- Parameters:
aMessage- The aMessage to be logged.aArguments- The arguments used when replacing the placeholders.
-
warn
Logs a log aMessage with log priorityLogPriority.WARN. "Warning messages, not an error, but indication that an error will occur if action is not taken, e.g. file system 85% full - each item must be resolved within a given time." See also http://en.wikipedia.org/wiki/Syslog- Specified by:
warnin interfaceRuntimeLogger- Parameters:
aMessage- The aMessage to be logged.aThrowable- An exception that the aMessage should contain.
-
warn
Logs a log aMessage with log priorityLogPriority.WARN. "Warning messages, not an error, but indication that an error will occur if action is not taken, e.g. file system 85% full - each item must be resolved within a given time." The placeholders in the aMessageStringare being replaced by the provided arguments. Implementations of this interface are recommended to use Java'sMessageFormat's syntax, the placeholder being replaced by the first argument is identified by "{0}" (without the quotes), the second one by "{1}", the third one by "{3}" and so on: Given the aMessage to be "{0} + {1} = {2}" and the three argument be x, y and x + y, then "{0}" is replaced by the value of x, "{1}" is replaced by the value of y and "{2}" is replaced by the value of x + y. See also http://en.wikipedia.org/wiki/Syslog- Specified by:
warnin interfaceRuntimeLogger- Parameters:
aMessage- The aMessage to be logged.aThrowable- An exception that the aMessage should contain.aArguments- The arguments used when replacing the placeholders.
-
isLogWarn
public boolean isLogWarn()Determines whether theRuntimeLoggeris being configured to log warnings (LogPriority.WARN). This method is useful to prevent the generation of vast amounts of log aMessageStringobjects (and according processing) for the accordingLogPriorityin case them messages of thatLogPriorityare not logged at all.- Specified by:
isLogWarnin interfaceRuntimeLogger- Returns:
- True in case warnings are logged.
-
error
Logs a log aMessage with log priorityLogPriority.ERROR. "Non-urgent failures, these should be relayed to developers or admins; each item must be resolved within a given time." See also http://en.wikipedia.org/wiki/Syslog- Specified by:
errorin interfaceRuntimeLogger- Parameters:
aMessage- The aMessage to be logged.
-
error
Logs a log aMessage with log priorityLogPriority.ERROR. "Non-urgent failures, these should be relayed to developers or admins; each item must be resolved within a given time." The placeholders in the aMessageStringare being replaced by the provided arguments. Implementations of this interface are recommended to use Java'sMessageFormat's syntax, the placeholder being replaced by the first argument is identified by "{0}" (without the quotes), the second one by "{1}", the third one by "{3}" and so on: Given the aMessage to be "{0} + {1} = {2}" and the three argument be x, y and x + y, then "{0}" is replaced by the value of x, "{1}" is replaced by the value of y and "{2}" is replaced by the value of x + y. See also http://en.wikipedia.org/wiki/Syslog- Specified by:
errorin interfaceRuntimeLogger- Parameters:
aMessage- The aMessage to be logged.aArguments- The arguments used when replacing the placeholders.
-
error
Logs a log aMessage with log priorityLogPriority.ERROR. "Non-urgent failures, these should be relayed to developers or admins; each item must be resolved within a given time." See also http://en.wikipedia.org/wiki/Syslog- Specified by:
errorin interfaceRuntimeLogger- Parameters:
aMessage- The aMessage to be logged.aThrowable- An exception that the aMessage should contain.
-
error
Logs a log aMessage with log priorityLogPriority.ERROR. "Non-urgent failures, these should be relayed to developers or admins; each item must be resolved within a given time." The placeholders in the aMessageStringare being replaced by the provided arguments. Implementations of this interface are recommended to use Java'sMessageFormat's syntax, the placeholder being replaced by the first argument is identified by "{0}" (without the quotes), the second one by "{1}", the third one by "{3}" and so on: Given the aMessage to be "{0} + {1} = {2}" and the three argument be x, y and x + y, then "{0}" is replaced by the value of x, "{1}" is replaced by the value of y and "{2}" is replaced by the value of x + y. See also http://en.wikipedia.org/wiki/Syslog- Specified by:
errorin interfaceRuntimeLogger- Parameters:
aMessage- The aMessage to be logged.aThrowable- An exception that the aMessage should contain.aArguments- The arguments used when replacing the placeholders.
-
isLogError
public boolean isLogError()Determines whether theRuntimeLoggeris being configured to log errors (LogPriority.ERROR). This method is useful to prevent the generation of vast amounts of log aMessageStringobjects (and according processing) for the accordingLogPriorityin case them messages of thatLogPriorityare not logged at all.- Specified by:
isLogErrorin interfaceRuntimeLogger- Returns:
- True in case errors are logged.
-
critical
Logs a log aMessage with log priorityLogPriority.CRITICAL. "Should be corrected immediately, but indicates failure in a secondary system, an example is a loss of a backup ISP connection." See also http://en.wikipedia.org/wiki/Syslog- Specified by:
criticalin interfaceRuntimeLogger- Parameters:
aMessage- The aMessage to be logged.
-
critical
Logs a log aMessage with log priorityLogPriority.CRITICAL. "Should be corrected immediately, but indicates failure in a secondary system, an example is a loss of a backup ISP connection." The placeholders in the aMessageStringare being replaced by the provided arguments. Implementations of this interface are recommended to use Java'sMessageFormat's syntax, the placeholder being replaced by the first argument is identified by "{0}" (without the quotes), the second one by "{1}", the third one by "{3}" and so on: Given the aMessage to be "{0} + {1} = {2}" and the three argument be x, y and x + y, then "{0}" is replaced by the value of x, "{1}" is replaced by the value of y and "{2}" is replaced by the value of x + y. See also http://en.wikipedia.org/wiki/Syslog- Specified by:
criticalin interfaceRuntimeLogger- Parameters:
aMessage- The aMessage to be logged.aArguments- The arguments used when replacing the placeholders.
-
critical
Logs a log aMessage with log priorityLogPriority.CRITICAL. "Should be corrected immediately, but indicates failure in a secondary system, an example is a loss of a backup ISP connection." See also http://en.wikipedia.org/wiki/Syslog- Specified by:
criticalin interfaceRuntimeLogger- Parameters:
aMessage- The aMessage to be logged.aThrowable- An exception that the aMessage should contain.
-
critical
Logs a log aMessage with log priorityLogPriority.CRITICAL. "Should be corrected immediately, but indicates failure in a secondary system, an example is a loss of a backup ISP connection." See also http://en.wikipedia.org/wiki/Syslog- Specified by:
criticalin interfaceRuntimeLogger- Parameters:
aMessage- The aMessage to be logged.aThrowable- An exception that the aMessage should contain.aArguments- The arguments used when replacing the placeholders.
-
isLogCritical
public boolean isLogCritical()Determines whether theRuntimeLoggeris being configured to log fatal messages (LogPriority.CRITICAL). This method is useful to prevent the generation of vast amounts of log aMessageStringobjects (and according processing) for the accordingLogPriorityin case them messages of thatLogPriorityare not logged at all.- Specified by:
isLogCriticalin interfaceRuntimeLogger- Returns:
- True in case fatal messages are logged.
-
alert
Logs a log aMessage with log priorityLogPriority.ALERT. "Should be corrected immediately, therefore notify staff who can fix the problem. An example would be the loss of a primary ISP connection." See also http://en.wikipedia.org/wiki/Syslog- Specified by:
alertin interfaceRuntimeLogger- Parameters:
aMessage- The aMessage to be logged.
-
alert
Logs a log aMessage with log priorityLogPriority.ALERT. "Should be corrected immediately, therefore notify staff who can fix the problem. An example would be the loss of a primary ISP connection." The placeholders in the aMessageStringare being replaced by the provided arguments. Implementations of this interface are recommended to use Java'sMessageFormat's syntax, the placeholder being replaced by the first argument is identified by "{0}" (without the quotes), the second one by "{1}", the third one by "{3}" and so on: Given the aMessage to be "{0} + {1} = {2}" and the three argument be x, y and x + y, then "{0}" is replaced by the value of x, "{1}" is replaced by the value of y and "{2}" is replaced by the value of x + y. See also http://en.wikipedia.org/wiki/Syslog- Specified by:
alertin interfaceRuntimeLogger- Parameters:
aMessage- The aMessage to be logged.aArguments- The arguments used when replacing the placeholders.
-
alert
Logs a log aMessage with log priorityLogPriority.ALERT.- Specified by:
alertin interfaceRuntimeLogger- Parameters:
aMessage- The aMessage to be logged.aThrowable- An exception that the aMessage should contain.
-
alert
Logs a log aMessage with log priorityLogPriority.ALERT.- Specified by:
alertin interfaceRuntimeLogger- Parameters:
aMessage- The aMessage to be logged.aThrowable- An exception that the aMessage should contain.aArguments- The arguments used when replacing the placeholders.
-
isLogAlert
public boolean isLogAlert()Determines whether theRuntimeLoggeris being configured to log fatal messages (LogPriority.ALERT). This method is useful to prevent the generation of vast amounts of log aMessageStringobjects (and according processing) for the accordingLogPriorityin case them messages of thatLogPriorityare not logged at all.- Specified by:
isLogAlertin interfaceRuntimeLogger- Returns:
- True in case fatal messages are logged.
-
panic
Logs a log aMessage with log priorityLogPriority.PANIC. "A "panic" condition usually affecting multiple apps/servers/sites. At this level it would usually notify all tech staff on call." ( See also http://en.wikipedia.org/wiki/Syslog- Specified by:
panicin interfaceRuntimeLogger- Parameters:
aMessage- The aMessage to be logged.
-
panic
Logs a log aMessage with log priorityLogPriority.PANIC. "A "panic" condition usually affecting multiple apps/servers/sites. At this level it would usually notify all tech staff on call." The placeholders in the aMessageStringare being replaced by the provided arguments. Implementations of this interface are recommended to use Java'sMessageFormat's syntax, the placeholder being replaced by the first argument is identified by "{0}" (without the quotes), the second one by "{1}", the third one by "{3}" and so on: Given the aMessage to be "{0} + {1} = {2}" and the three argument be x, y and x + y, then "{0}" is replaced by the value of x, "{1}" is replaced by the value of y and "{2}" is replaced by the value of x + y. See also http://en.wikipedia.org/wiki/Syslog- Specified by:
panicin interfaceRuntimeLogger- Parameters:
aMessage- The aMessage to be logged.aArguments- The arguments used when replacing the placeholders.
-
panic
Logs a log aMessage with log priorityLogPriority.PANIC. "A "panic" condition usually affecting multiple apps/servers/sites. At this level it would usually notify all tech staff on call." ( See also http://en.wikipedia.org/wiki/Syslog- Specified by:
panicin interfaceRuntimeLogger- Parameters:
aMessage- The aMessage to be logged.aThrowable- An exception that the aMessage should contain.
-
panic
Logs a log aMessage with log priorityLogPriority.PANIC. "A "panic" condition usually affecting multiple apps/servers/sites. At this level it would usually notify all tech staff on call." The placeholders in the aMessageStringare being replaced by the provided arguments. Implementations of this interface are recommended to use Java'sMessageFormat's syntax, the placeholder being replaced by the first argument is identified by "{0}" (without the quotes), the second one by "{1}", the third one by "{3}" and so on: Given the aMessage to be "{0} + {1} = {2}" and the three argument be x, y and x + y, then "{0}" is replaced by the value of x, "{1}" is replaced by the value of y and "{2}" is replaced by the value of x + y. See also http://en.wikipedia.org/wiki/Syslog- Specified by:
panicin interfaceRuntimeLogger- Parameters:
aMessage- The aMessage to be logged.aThrowable- An exception that the aMessage should contain.aArguments- The arguments used when replacing the placeholders.
-
isLogPanic
public boolean isLogPanic()Determines whether theRuntimeLoggeris being configured to log fatal messages (LogPriority.PANIC). This method is useful to prevent the generation of vast amounts of log aMessageStringobjects (and according processing) for the accordingLogPriorityin case them messages of thatLogPriorityare not logged at all.- Specified by:
isLogPanicin interfaceRuntimeLogger- Returns:
- True in case fatal messages are logged.
-