Uses of Enum Class
org.refcodes.logger.ColumnLayout
-
Uses of ColumnLayout in org.refcodes.logger
Subclasses with type arguments of type ColumnLayout in org.refcodes.loggerModifier and TypeClassDescriptionenumPredefined layouts passed to logger implementation supportingColumnLayoutmodes.Methods in org.refcodes.logger that return ColumnLayoutModifier and TypeMethodDescriptionColumnLayoutAccessor.getColumnLayout()Retrieves the column layout from the column layout property.default ColumnLayoutColumnLayoutAccessor.ColumnLayoutProperty.letColumnLayout(ColumnLayout aColumnLayout) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenColumnLayout(setter) as ofColumnLayoutAccessor.ColumnLayoutMutator.setColumnLayout(ColumnLayout)and returns the very same value (getter).static ColumnLayoutColumnLayout.toColumnLayout(String aValue) Case insensitive convenience method for converting aStringto an according enumeration.static ColumnLayoutReturns the enum constant of this class with the specified name.static ColumnLayout[]ColumnLayout.values()Returns an array containing the constants of this enum class, in the order they are declared.Methods in org.refcodes.logger with parameters of type ColumnLayoutModifier and TypeMethodDescriptiondefault ColumnLayoutColumnLayoutAccessor.ColumnLayoutProperty.letColumnLayout(ColumnLayout aColumnLayout) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenColumnLayout(setter) as ofColumnLayoutAccessor.ColumnLayoutMutator.setColumnLayout(ColumnLayout)and returns the very same value (getter).voidColumnLayoutAccessor.ColumnLayoutMutator.setColumnLayout(ColumnLayout aColumnLayout) Sets the column layout for the column layout property.ColumnLayoutAccessor.ColumnLayoutBuilder.withColumnLayout(ColumnLayout aColumnLayout) Sets the column layout for the column layout property.