Uses of Interface
org.refcodes.logger.Logger
-
Uses of Logger in org.refcodes.logger
Classes in org.refcodes.logger with type parameters of type LoggerModifier and TypeInterfaceDescriptioninterfaceLoggerAccessor<L extends Logger<?>>Provides an accessor for aLoggerproperty.static interfaceLoggerAccessor.LoggerMutator<L extends Logger<?>>Provides a mutator for aLoggerproperty.static interfaceLoggerAccessor.LoggerProperty<L extends Logger<?>>Provides aLoggerproperty.interfaceLoggerFactory<L extends Logger<?>>ALoggerFactorydefines the methods required to factorLoggerinstances.Subinterfaces of Logger in org.refcodes.loggerModifier and TypeInterfaceDescriptioninterfaceQueryLogger<T>TheQueryLoggerextends theLogger; providing additional functionality for querying once logged dataRecordsby specifying queryCriteriaor other query restrictions.interfaceTrimLogger<T>TheTrimLoggerextends theQueryLoggerwith the functionality to removeRecordinstances previously being logged by providing the accordingCriteria.Classes in org.refcodes.logger that implement LoggerModifier and TypeClassDescriptionclassTheLoggerDispatcherclass extends theAbstractLoggerDispatcherand represents an asynchronous logger composite delegating to encapsulated logger instances with a log lines queue.classPartedLogger<T, P extends T>ThePartedLoggeris a ready to use implementation of a partedLoggerextending theAbstractPartedLogger.classPartedQueryLogger<T, P extends T>ThePartedQueryLoggeris a ready to use implementation of a partedQueryLoggerextending theAbstractPartedQueryLogger.classPartedTrimLogger<T, P extends T>ThePartedTrimLoggeris a ready to use implementation of a partedTrimLoggerextending theAbstractPartedTrimLogger.classTheQueryLoggerDispatcheris a ready to use implementation of a compositeQueryLoggerextending theAbstractQueryLoggerDispatcher.classVery plain implementation of the logger interface, mainly used as fallbackLogger.classTheTrimLoggerDispatcheris a ready to use implementation of a compositeTrimLoggerextending theAbstractTrimLoggerDispatcher.Subclasses with type arguments of type Logger in org.refcodes.loggerModifier and TypeClassDescriptionclassTheLoggerDispatcherclass extends theAbstractLoggerDispatcherand represents an asynchronous logger composite delegating to encapsulated logger instances with a log lines queue.classSpecialization and instantiateable (non abstract) implementation of theAbstractLoggerFactoryCompositecreating compositeLoggerinstances.classPartedLogger<T, P extends T>ThePartedLoggeris a ready to use implementation of a partedLoggerextending theAbstractPartedLogger.Classes in org.refcodes.logger that implement interfaces with type arguments of type LoggerModifier and TypeClassDescriptionclassThe default implementation of theRuntimeLoggerinterface to be configured with a (back-end)Logger.Methods in org.refcodes.logger that return LoggerModifier and TypeMethodDescriptionLoggerFactoryComposite.createCompositeLogger(Logger<T>[] aLoggers) To be implemented by sub-classes, this method creates aLoggerDispatcher(or its sub-classes) from the providedLoggerinstances (or its sub-types).DefaultRuntimeLogger.getLogger()Retrieves the logger from the logger property.Methods in org.refcodes.logger with parameters of type LoggerModifier and TypeMethodDescriptionLoggerFactoryComposite.createCompositeLogger(Logger<T>[] aLoggers) To be implemented by sub-classes, this method creates aLoggerDispatcher(or its sub-classes) from the providedLoggerinstances (or its sub-types).voidSets the logger for the logger property.Constructors in org.refcodes.logger with parameters of type LoggerModifierConstructorDescriptionDefaultRuntimeLogger(String aName, Logger<Object> aLogger) Constructs aRuntimeLoggerlogging with the givenLoggerand the desiredLogPriorityfor the messages being logged and upwards (from the givenLogPriority.getPriority()and higher).DefaultRuntimeLogger(String aName, Logger<Object> aLogger, LogPriority aPriority) Constructs aRuntimeLoggerlogging with the givenLoggerand the desiredLogPriorityfor the messages being logged and upwards (from the givenLogPriority.getPriority()and higher).DefaultRuntimeLogger(Logger<Object> aLogger) Constructs aRuntimeLoggerlogging with the givenLoggerand the desiredLogPriorityfor the messages being logged and upwards (from the givenLogPriority.getPriority()and higher).DefaultRuntimeLogger(Logger<Object> aLogger, LogPriority aPriority) Constructs aRuntimeLoggerlogging with the givenLoggerand the desiredLogPriorityfor the messages being logged and upwards (from the givenLogPriority.getPriority()and higher).LoggerDispatcher(ExecutionStrategy aComponentExecutionStrategy, Logger<T>... aLoggers) Similar to theLoggerDispatcher(Logger...)with the additional option of determining the execution strategy of the state change request calls for the encapsulatedLoggerinstances (as ofComponentComposite).LoggerDispatcher(Logger<T>... aLoggers) Instantiates a newLoggerDispatchercomposed of the providedLoggerinstances.Constructor parameters in org.refcodes.logger with type arguments of type LoggerModifierConstructorDescriptionLoggerFactoryComposite(LoggerFactory<Logger<T>> aLoggerFactory, int aNumEndpoints) Instantiates a new composite logger factory impl.PartedLogger(ExecutionStrategy aComponentExecutionStrategy, Column<P> aPartitionColumn, String aDefaultLoggerName, LoggerFactory<Logger<T>> aLoggerFactory, boolean isPartitionAutoInitialize) Similar to thePartedLogger(Column, LoggerFactory, boolean)with the additional option of determining the execution strategy of the state change request calls for the encapsulatedLoggerinstances (as ofComponentComposite).PartedLogger(ExecutionStrategy aComponentExecutionStrategy, Column<P> aPartitionColumn, LoggerFactory<Logger<T>> aLoggerFactory, boolean isPartitionAutoInitialize) Similar to thePartedLogger(Column, LoggerFactory, boolean)with the additional option of determining the execution strategy of the state change request calls for the encapsulatedLoggerinstances (as ofComponentComposite).PartedLogger(Column<P> aPartitionColumn, String aDefaultLoggerName, LoggerFactory<Logger<T>> aLoggerFactory, boolean isPartitionAutoInitialize) Instantiates a newPartedLoggerwith the according parameters.PartedLogger(Column<P> aPartitionColumn, LoggerFactory<Logger<T>> aLoggerFactory, boolean isPartitionAutoInitialize) Instantiates a newPartedLoggerwith the according parameters.