Uses of Interface
org.refcodes.logger.LoggerFactory
-
Uses of LoggerFactory in org.refcodes.logger
Classes in org.refcodes.logger that implement LoggerFactoryModifier and TypeClassDescriptionclassSpecialization and instantiateable (non abstract) implementation of theAbstractLoggerFactoryCompositecreating compositeLoggerinstances.classImplementation of theAbstractLoggerFactoryCompositecreating compositeQueryLoggerinstances.classSpecialization and instantiateable (non abstract) implementation of theAbstractLoggerFactoryCompositecreating compositeTrimLoggerinstances.Constructors in org.refcodes.logger with parameters of type LoggerFactoryModifierConstructorDescriptionLoggerFactoryComposite(LoggerFactory<Logger<T>> aLoggerFactory, int aNumEndpoints) Instantiates a new composite logger factory impl.PartedLogger(ExecutionStrategy aComponentExecutionStrategy, Column<P> aPartitionColumn, String aDefaultLoggerName, LoggerFactory<Logger<T>> aLoggerFactory, boolean isPartitionAutoInitialize) Similar to thePartedLogger(Column, LoggerFactory, boolean)with the additional option of determining the execution strategy of the state change request calls for the encapsulatedLoggerinstances (as ofComponentComposite).PartedLogger(ExecutionStrategy aComponentExecutionStrategy, Column<P> aPartitionColumn, LoggerFactory<Logger<T>> aLoggerFactory, boolean isPartitionAutoInitialize) Similar to thePartedLogger(Column, LoggerFactory, boolean)with the additional option of determining the execution strategy of the state change request calls for the encapsulatedLoggerinstances (as ofComponentComposite).PartedLogger(Column<P> aPartitionColumn, String aDefaultLoggerName, LoggerFactory<Logger<T>> aLoggerFactory, boolean isPartitionAutoInitialize) Instantiates a newPartedLoggerwith the according parameters.PartedLogger(Column<P> aPartitionColumn, LoggerFactory<Logger<T>> aLoggerFactory, boolean isPartitionAutoInitialize) Instantiates a newPartedLoggerwith the according parameters.PartedQueryLogger(ExecutionStrategy aComponentExecutionStrategy, Column<P> aPartitionColumn, String aDefaultLoggerName, LoggerFactory<QueryLogger<T>> aLoggerFactory, boolean isPartitionAutoInitialize) Similar to thePartedQueryLogger(Column, LoggerFactory, boolean)with the additional option of determining the execution strategy of the state change request calls for the encapsulatedQueryLoggerinstances (as ofComponentComposite).PartedQueryLogger(ExecutionStrategy aComponentExecutionStrategy, Column<P> aPartitionColumn, LoggerFactory<QueryLogger<T>> aLoggerFactory, boolean isPartitionAutoInitialize) Similar to thePartedQueryLogger(Column, LoggerFactory, boolean)with the additional option of determining the execution strategy of the state change request calls for the encapsulatedQueryLoggerinstances (as ofComponentComposite).PartedQueryLogger(Column<P> aPartitionColumn, String aDefaultLoggerName, LoggerFactory<QueryLogger<T>> aLoggerFactory, boolean isPartitionAutoInitialize) Instantiates a newPartedQueryLoggerwith the according parameters.PartedQueryLogger(Column<P> aPartitionColumn, LoggerFactory<QueryLogger<T>> aLoggerFactory, boolean isPartitionAutoInitialize) Instantiates a newPartedQueryLoggerwith the according parameters.PartedTrimLogger(ExecutionStrategy aComponentExecutionStrategy, Column<P> aPartitionColumn, String aDefaultLoggerName, LoggerFactory<TrimLogger<T>> aLoggerFactory, boolean isPartitionAutoInitialize) Similar to thePartedTrimLogger(Column, LoggerFactory, boolean)constructor with the additional option of determining the execution strategy of the state change request calls for the encapsulatedTrimLoggerinstances (as ofComponentComposite).PartedTrimLogger(ExecutionStrategy aComponentExecutionStrategy, Column<P> aPartitionColumn, LoggerFactory<TrimLogger<T>> aLoggerFactory, boolean isPartitionAutoInitialize) Similar to thePartedTrimLogger(Column, LoggerFactory, boolean)constructor with the additional option of determining the execution strategy of the state change request calls for the encapsulatedTrimLoggerinstances (as ofComponentComposite).PartedTrimLogger(Column<P> aPartitionColumn, String aDefaultLoggerName, LoggerFactory<TrimLogger<T>> aLoggerFactory, boolean isPartitionAutoInitialize) Instantiates a newPartedTrimLoggerwith the according parameters.PartedTrimLogger(Column<P> aPartitionColumn, LoggerFactory<TrimLogger<T>> aLoggerFactory, boolean isPartitionAutoInitialize) Instantiates a newPartedTrimLoggerwith the according parameters.QueryLoggerFactoryComposite(LoggerFactory<QueryLogger<T>> aLoggerFactory, int aNumEndpoints) Instantiates a new composite query logger factory impl.TrimLoggerFactoryComposite(LoggerFactory<TrimLogger<T>> aLoggerFactory, int aNumEndpoints) Instantiates a new composite trim logger factory impl.