Thrown in case the record cannot be logged as a specific implementation might
expect some dedicated Column instances to be contained in the
provided Record.
Thrown in case instantiating a Logger (RuntimeLogger) failed,
e.g. the RuntimeLoggerSingleton tries to construct a
RuntimeLogger from a bean configuration file (or a
SpringRuntimeLoggerSingleton tries to construct a RuntimeLogger from
a bean configuration context file) and fails doing so (due to missing or
"wrong" configuration file).