All Classes and Interfaces
Class
Description
Predefined layouts passed to logger implementation supporting
ColumnLayout modes.Provides an accessor for a column layout property.
Provides a builder method for a column layout property returning the
builder for applying multiple build operations.
Provides a mutator for a column layout property.
Provides a column layout property.
Thrown in case the record cannot be logged as a specific implementation might
expect some dedicated
Column instances to be contained in the
provided Record.The
LogDecorator provides means to beautify or enrich logs for
example when printing user friendly logs to the console.The
Logger interface defines those methods required for an atomic
(sub-)logger to implement.Provides an accessor for a
Logger property.Provides a mutator for a
Logger property.Provides a
Logger property.The
LoggerComposite is a ready to use implementation of a composite
Logger extending the AbstractLoggerComposite.A
LoggerFactory defines the methods required to factor Logger
instances.Specialization and instantiateable (non abstract) implementation of the
AbstractLoggerFactoryComposite creating composite Logger
instances.Defines default logger
Header.Thrown in case instantiating a
Logger (RuntimeLogger) failed,
e.g. the RuntimeLoggerSingleton tries to construct a
RuntimeLogger from a bean configuration file (or a
SpringRuntimeLoggerSingleton tries to construct a RuntimeLogger from
a bean configuration context file) and fails doing so (due to missing or
"wrong" configuration file).The Class
LoggerRuntimeException.The Class LoggerUtility.
This enumeration defines the various log priorities to be used by the
application logger.
Provides an accessor for a
LogPriority property.Provides a mutator for a
LogPriority property.Provides a
LogPriority property.The aMessage logger is the generic version of the
RuntimeLogger.The
PartedLogger is a ready to use implementation of a parted
Logger extending the AbstractPartedLogger.The
PartedQueryLogger is a ready to use implementation of a parted
QueryLogger extending the AbstractPartedQueryLogger.The
PartedTrimLogger is a ready to use implementation of a parted
TrimLogger extending the AbstractPartedTrimLogger.The
QueryLogger extends the Logger; providing additional
functionality for querying once logged data Records by specifying
query Criteria or other query restrictions.The
QueryLoggerComposite is a ready to use implementation of a
composite QueryLogger extending the
AbstractQueryLoggerComposite.Implementation of the
AbstractLoggerFactoryComposite creating
composite QueryLogger instances.
Plain simple interface for logging out runtime information generated by
software systems.
Provides an accessor for a
RuntimeLogger property.Provides a mutator for a
RuntimeLogger property.Provides a
RuntimeLogger property.A
RuntimeLoggerFactory defines the methods required to factor
RuntimeLogger instances.You configure your
RuntimeLoggerFactoryImpl by providing a
"runtimelogger.ini" file (see
"http://www.refcodes.org/refcodes/refcodes-logger") in one of those locations
relative to your main class's location:
.
.The singleton of the
RuntimeLoggerFactoryImpl for easy
RuntimeLogger creation.The
RuntimeLoggerHandler provides a Handler for the JUL
Framework.The Class RuntimeLoggerHeader.
The default implementation of the
RuntimeLogger interface to be
configured with a (back-end) Logger.
This
RuntimeLoggerSingleton provides a RuntimeLogger
singleton configured by a "runtimelogger-config.xml" file find
in one of the several locations relative to your application's base
directory: The applications base directory (where your JAR or your classes
reside) is taken and a list of directories (as defined in the
Folders.CONFIG_DIRS) relative to this base directory is generated :
The actual directories being looked at (in case them exist) are as follows,
relative to your applications base directory:Very plain implementation of the logger interface, mainly used as fallback
Logger.The
TrimLogger extends the QueryLogger with the functionality
to remove Record instances previously being logged by providing the
according Criteria.The
TrimLoggerComposite is a ready to use implementation of a
composite TrimLogger extending the
AbstractTrimLoggerComposite.Specialization and instantiateable (non abstract) implementation of the
AbstractLoggerFactoryComposite creating composite TrimLogger
instances.Thrown in case some other problems regarding logging occurred, e.g. the data
sink (physical system where to log to) experiences problems.