Interface LoggerFactory<L extends Logger<?>>
- Type Parameters:
L- the generic type
- All Superinterfaces:
org.refcodes.factory.LookupFactory<L,String>
- All Known Implementing Classes:
LoggerFactoryComposite,QueryLoggerFactoryComposite,TrimLoggerFactoryComposite
public interface LoggerFactory<L extends Logger<?>>
extends org.refcodes.factory.LookupFactory<L,String>
A
LoggerFactory defines the methods required to factor Logger
instances. You might also provide a static method with the following
signature in order to provide singleton functionality and avoid to create too
many unnecessary Logger instances:
public Logger getInstance() { ... }
-
Method Summary
Methods inherited from interface org.refcodes.factory.LookupFactory
create, create