Interface QueryLogger<T>
- All Superinterfaces:
LogDecorator, Logger<T>
- All Known Subinterfaces:
TrimLogger<T>
- All Known Implementing Classes:
PartedQueryLogger, PartedTrimLogger, QueryLoggerDispatcher, TrimLoggerDispatcher
The
QueryLogger extends the Logger; providing additional
functionality for querying once logged data Records by specifying
query Criteria or other query restrictions.-
Method Summary
Modifier and TypeMethodDescriptionfindLogs()Retrieves all availableRecordinstances being logged.findLogs(int aLimit) Retrieves all availableRecordinstances being logged matching the given criteria and restrictions.Retrieves all availableRecordinstances being logged matching the given criteria and restrictions.Retrieves all availableRecordinstances being logged matching the given criteria and restrictions.Retrieves all availableRecordinstances being logged matching the given criteria and restrictions.Retrieves all availableRecordinstances being logged matching the given criteria and restrictions.Retrieves all availableRecordinstances being logged matching the given criteria and restrictions.Methods inherited from interface LogDecorator
printHead, printSeparator, printTail
-
Method Details
-
findLogs
-
findLogs
Retrieves all availableRecordinstances being logged matching the given criteria and restrictions.- Parameters:
aLimit- The maximumRecordinstances contained in the returnedRecordsinstance; there may be moreRecordinstances which are not contained in theRecordsinstance in case theRecordsinstance's size is that of the specified limit.- Returns:
- A
Recordsinstance containing all availableRecordinstances being logged matching the given criteria and restrictions.
-
findLogs
Retrieves all availableRecordinstances being logged matching the given criteria and restrictions.- Parameters:
aHeader- TheHeaderused to restrict the "columns" (key/value entries) in the retrievedRecordinstances (provided by theRecordsinstance).aLimit- The maximumRecordinstances contained in the returnedRecordsinstance; there may be moreRecordinstances which are not contained in theRecordsinstance in case theRecordsinstance's size is that of the specified limit.- Returns:
- A
Recordsinstance containing all availableRecordinstances being logged matching the given criteria and restrictions.
-
findLogs
Retrieves all availableRecordinstances being logged matching the given criteria and restrictions. -
findLogs
Retrieves all availableRecordinstances being logged matching the given criteria and restrictions.- Parameters:
aCriteria- TheCriteriato be applied to theRecordinstancesaLimit- The maximumRecordinstances contained in the returnedRecordsinstance; there may be moreRecordinstances which are not contained in theRecordsinstance in case theRecordsinstance's size is that of the specified limit.- Returns:
- A
Recordsinstance containing all availableRecordinstances being logged matching the given criteria and restrictions. - Throws:
BadCriteriaException- thrown in case of problems related to someCriteria.
-
findLogs
Retrieves all availableRecordinstances being logged matching the given criteria and restrictions.- Parameters:
aCriteria- TheCriteriato be applied to theRecordinstancesaHeader- TheHeaderused to restrict the "columns" (key/value entries) in the retrievedRecordinstances (provided by theRecordsinstance).- Returns:
- A
Recordsinstance containing all availableRecordinstances being logged matching the given criteria and restrictions. - Throws:
BadCriteriaException- thrown in case of problems related to someCriteria.
-
findLogs
Retrieves all availableRecordinstances being logged matching the given criteria and restrictions.- Parameters:
aCriteria- TheCriteriato be applied to theRecordinstancesaHeader- TheHeaderused to restrict the "columns" (key/value entries) in the retrievedRecordinstances (provided by theRecordsinstance).aLimit- The maximumRecordinstances contained in the returnedRecordsinstance; there may be moreRecordinstances which are not contained in theRecordsinstance in case theRecordsinstance's size is that of the specified limit.- Returns:
- A
Recordsinstance containing all availableRecordinstances being logged matching the given criteria and restrictions. - Throws:
BadCriteriaException- thrown in case of problems related to someCriteria.
-