Interface QueryLogger<T>
- Type Parameters:
T- The type of theRecordinstances managed by theLogger.
- All Superinterfaces:
LogDecorator,Logger<T>
- All Known Subinterfaces:
TrimLogger<T>
- All Known Implementing Classes:
PartedQueryLogger,PartedTrimLogger,QueryLoggerComposite,TrimLoggerComposite
The
QueryLogger extends the Logger; providing additional
functionality for querying once logged data Records by specifying
query Criteria or other query restrictions.-
Method Summary
Modifier and TypeMethodDescriptionorg.refcodes.tabular.Records<T> findLogs()Retrieves all availableRecordinstances being logged.org.refcodes.tabular.Records<T> findLogs(int aLimit) Retrieves all availableRecordinstances being logged matching the given criteria and restrictions.org.refcodes.tabular.Records<T> findLogs(org.refcodes.criteria.Criteria aCriteria) Retrieves all availableRecordinstances being logged matching the given criteria and restrictions.org.refcodes.tabular.Records<T> findLogs(org.refcodes.criteria.Criteria aCriteria, int aLimit) Retrieves all availableRecordinstances being logged matching the given criteria and restrictions.org.refcodes.tabular.Records<T> Retrieves all availableRecordinstances being logged matching the given criteria and restrictions.org.refcodes.tabular.Records<T> findLogs(org.refcodes.criteria.Criteria aCriteria, org.refcodes.tabular.Header<T> aHeader, int aLimit) Retrieves all availableRecordinstances being logged matching the given criteria and restrictions.org.refcodes.tabular.Records<T> Retrieves all availableRecordinstances being logged matching the given criteria and restrictions.Methods inherited from interface org.refcodes.logger.LogDecorator
printHead, printSeparator, printTail
-
Method Details
-
findLogs
org.refcodes.tabular.Records<T> findLogs()Retrieves all availableRecordinstances being logged.- Returns:
- A
Recordsinstance containing all availableRecordinstances being logged.
-
findLogs
Retrieves all availableRecordinstances being logged matching the given criteria and restrictions.- Parameters:
aLimit- The maximumRecordinstances contained in the returnedRecordsinstance; there may be moreRecordinstances which are not contained in theRecordsinstance in case theRecordsinstance's size is that of the specified limit.- Returns:
- A
Recordsinstance containing all availableRecordinstances being logged matching the given criteria and restrictions.
-
findLogs
Retrieves all availableRecordinstances being logged matching the given criteria and restrictions.- Parameters:
aHeader- TheHeaderused to restrict the "columns" (key/value entries) in the retrievedRecordinstances (provided by theRecordsinstance).aLimit- The maximumRecordinstances contained in the returnedRecordsinstance; there may be moreRecordinstances which are not contained in theRecordsinstance in case theRecordsinstance's size is that of the specified limit.- Returns:
- A
Recordsinstance containing all availableRecordinstances being logged matching the given criteria and restrictions.
-
findLogs
org.refcodes.tabular.Records<T> findLogs(org.refcodes.criteria.Criteria aCriteria) throws org.refcodes.criteria.BadCriteriaException Retrieves all availableRecordinstances being logged matching the given criteria and restrictions.- Parameters:
aCriteria- TheCriteriato be applied to theRecordinstances- Returns:
- A
Recordsinstance containing all availableRecordinstances being logged matching the given criteria and restrictions. - Throws:
org.refcodes.criteria.BadCriteriaException- thrown in case of problems related to someCriteria.
-
findLogs
org.refcodes.tabular.Records<T> findLogs(org.refcodes.criteria.Criteria aCriteria, int aLimit) throws org.refcodes.criteria.BadCriteriaException Retrieves all availableRecordinstances being logged matching the given criteria and restrictions.- Parameters:
aCriteria- TheCriteriato be applied to theRecordinstancesaLimit- The maximumRecordinstances contained in the returnedRecordsinstance; there may be moreRecordinstances which are not contained in theRecordsinstance in case theRecordsinstance's size is that of the specified limit.- Returns:
- A
Recordsinstance containing all availableRecordinstances being logged matching the given criteria and restrictions. - Throws:
org.refcodes.criteria.BadCriteriaException- thrown in case of problems related to someCriteria.
-
findLogs
org.refcodes.tabular.Records<T> findLogs(org.refcodes.criteria.Criteria aCriteria, org.refcodes.tabular.Header<T> aHeader) throws org.refcodes.criteria.BadCriteriaException Retrieves all availableRecordinstances being logged matching the given criteria and restrictions.- Parameters:
aCriteria- TheCriteriato be applied to theRecordinstancesaHeader- TheHeaderused to restrict the "columns" (key/value entries) in the retrievedRecordinstances (provided by theRecordsinstance).- Returns:
- A
Recordsinstance containing all availableRecordinstances being logged matching the given criteria and restrictions. - Throws:
org.refcodes.criteria.BadCriteriaException- thrown in case of problems related to someCriteria.
-
findLogs
org.refcodes.tabular.Records<T> findLogs(org.refcodes.criteria.Criteria aCriteria, org.refcodes.tabular.Header<T> aHeader, int aLimit) throws org.refcodes.criteria.BadCriteriaException Retrieves all availableRecordinstances being logged matching the given criteria and restrictions.- Parameters:
aCriteria- TheCriteriato be applied to theRecordinstancesaHeader- TheHeaderused to restrict the "columns" (key/value entries) in the retrievedRecordinstances (provided by theRecordsinstance).aLimit- The maximumRecordinstances contained in the returnedRecordsinstance; there may be moreRecordinstances which are not contained in theRecordsinstance in case theRecordsinstance's size is that of the specified limit.- Returns:
- A
Recordsinstance containing all availableRecordinstances being logged matching the given criteria and restrictions. - Throws:
org.refcodes.criteria.BadCriteriaException- thrown in case of problems related to someCriteria.
-