Class QueryLoggerDispatcher<T>
java.lang.Object
org.refcodes.logger.QueryLoggerDispatcher<T>
- All Implemented Interfaces:
Flushable, Closable, ComponentComposite, Decomposable, Destroyable, Flushable, Initializable, LifecycleComponent, LinkComponent, Openable, Pausable, Resumable, Startable, Stoppable, LogDecorator, Logger<T>, QueryLogger<T>, Disposable, Resetable
The
QueryLoggerDispatcher is a ready to use implementation of a
composite QueryLogger extending the
AbstractQueryLoggerDispatcher.- See Also:
-
Nested Class Summary
Nested classes/interfaces inherited from interface Closable
Closable.CloseAutomaton, Closable.CloseBuilder<B>Nested classes/interfaces inherited from interface ComponentComposite
ComponentComposite.ExtendedComponentComposite<CTX,CON> Nested classes/interfaces inherited from interface Decomposable
Decomposable.DecomposeAutomatonNested classes/interfaces inherited from interface Destroyable
Destroyable.DestroyAutomatonNested classes/interfaces inherited from interface Flushable
Flushable.FlushBuilder<B>Nested classes/interfaces inherited from interface Initializable
Initializable.InitializeAutomaton, Initializable.InitializeBuilder<B>, Initializable.UncheckedInitializableNested classes/interfaces inherited from interface LifecycleComponent
LifecycleComponent.LifecycleAutomaton, LifecycleComponent.UncheckedLifecycleComponentNested classes/interfaces inherited from interface LinkComponent
LinkComponent.LinkAutomaton, LinkComponent.LinkComponentBuilder<B>Nested classes/interfaces inherited from interface Openable
Openable.OpenAutomaton, Openable.OpenBuilder<B>Nested classes/interfaces inherited from interface Pausable
Pausable.PauseAutomaton, Pausable.PauseBuilder<B>, Pausable.UncheckedPausableNested classes/interfaces inherited from interface Resumable
Resumable.ResumeAutomaton, Resumable.ResumeBuilder<B>, Resumable.UncheckedResumableNested classes/interfaces inherited from interface Startable
Startable.StartAutomaton, Startable.StartBuilder<B>, Startable.UncheckedStartableNested classes/interfaces inherited from interface Stoppable
Stoppable.StopAutomaton, Stoppable.StopBuilder<B>, Stoppable.UncheckedStoppable -
Constructor Summary
ConstructorsConstructorDescriptionQueryLoggerDispatcher(ExecutionStrategy aComponentExecutionStrategy, QueryLogger<T>... aLoggers) Similar to theQueryLoggerDispatcher(QueryLogger...)with the additional option of determining the execution strategy of the state change request calls for the encapsulatedQueryLoggerinstances (as ofComponentComposite).QueryLoggerDispatcher(QueryLogger<T>... aLoggers) Instantiates a newQueryLoggerDispatchercomposed of the providedQueryLoggerinstances. -
Method Summary
Modifier and TypeMethodDescriptionvoidclose()voidvoiddestroy()voiddispose()findLogs()Retrieves all availableRecordinstances being logged.findLogs(int aLimit) Retrieves all availableRecordinstances being logged matching the given criteria and restrictions.Retrieves all availableRecordinstances being logged matching the given criteria and restrictions.Retrieves all availableRecordinstances being logged matching the given criteria and restrictions.Retrieves all availableRecordinstances being logged matching the given criteria and restrictions.Retrieves all availableRecordinstances being logged matching the given criteria and restrictions.Retrieves all availableRecordinstances being logged matching the given criteria and restrictions.voidflush()protected Collection<QueryLogger<T>> Gets the loggers.voidvoidLogs aRecord.voidopen()voidpause()voidreset()voidresume()voidstart()voidstop()Methods inherited from class Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, waitMethods inherited from interface Closable
closeIn, closeQuietly, closeUncheckedMethods inherited from interface Flushable
flushUnchecked, isFlushableMethods inherited from interface Initializable
initializeUncheckedMethods inherited from interface LogDecorator
printHead, printSeparator, printTailMethods inherited from interface Openable
openUncheckedMethods inherited from interface Pausable
pauseUncheckedMethods inherited from interface Resumable
resumeUncheckedMethods inherited from interface Startable
startUncheckedMethods inherited from interface Stoppable
stopUnchecked
-
Constructor Details
-
QueryLoggerDispatcher
Instantiates a newQueryLoggerDispatchercomposed of the providedQueryLoggerinstances.- Parameters:
aLoggers- theLoggerinstances populating this composite.- See Also:
-
QueryLoggerDispatcher
@SafeVarargs public QueryLoggerDispatcher(ExecutionStrategy aComponentExecutionStrategy, QueryLogger<T>... aLoggers) Similar to theQueryLoggerDispatcher(QueryLogger...)with the additional option of determining the execution strategy of the state change request calls for the encapsulatedQueryLoggerinstances (as ofComponentComposite).- Parameters:
aComponentExecutionStrategy- The strategy to be used when invoking a component's (encapsulatedQueryLoggerinstance's) state change request call (as ofComponentComposite).aLoggers- theQueryLoggerinstances populating this composite.
-
-
Method Details
-
initialize
- Specified by:
initializein interfaceInitializable- Throws:
InitializeException
-
start
- Specified by:
startin interfaceStartable- Throws:
StartException
-
pause
- Specified by:
pausein interfacePausable- Throws:
PauseException
-
resume
- Specified by:
resumein interfaceResumable- Throws:
ResumeException
-
stop
- Specified by:
stopin interfaceStoppable- Throws:
StopException
-
decompose
public void decompose()- Specified by:
decomposein interfaceDecomposable
-
flush
- Specified by:
flushin interfaceFlushable- Specified by:
flushin interfaceFlushable- Throws:
IOException
-
destroy
public void destroy()- Specified by:
destroyin interfaceDestroyable
-
reset
-
open
- Specified by:
openin interfaceOpenable- Throws:
IOException
-
close
-
dispose
public void dispose()- Specified by:
disposein interfaceDisposable
-
findLogs
Retrieves all availableRecordinstances being logged.- Specified by:
findLogsin interfaceQueryLogger<L extends QueryLogger<T>>- Returns:
- A
Recordsinstance containing all availableRecordinstances being logged.
-
findLogs
Retrieves all availableRecordinstances being logged matching the given criteria and restrictions.- Specified by:
findLogsin interfaceQueryLogger<L extends QueryLogger<T>>- Parameters:
aLimit- The maximumRecordinstances contained in the returnedRecordsinstance; there may be moreRecordinstances which are not contained in theRecordsinstance in case theRecordsinstance's size is that of the specified limit.- Returns:
- A
Recordsinstance containing all availableRecordinstances being logged matching the given criteria and restrictions.
-
findLogs
Retrieves all availableRecordinstances being logged matching the given criteria and restrictions.- Specified by:
findLogsin interfaceQueryLogger<L extends QueryLogger<T>>- Parameters:
aCriteria- TheCriteriato be applied to theRecordinstances- Returns:
- A
Recordsinstance containing all availableRecordinstances being logged matching the given criteria and restrictions.
-
findLogs
Retrieves all availableRecordinstances being logged matching the given criteria and restrictions.- Specified by:
findLogsin interfaceQueryLogger<L extends QueryLogger<T>>- Parameters:
aHeader- TheHeaderused to restrict the "columns" (key/value entries) in the retrievedRecordinstances (provided by theRecordsinstance).aLimit- The maximumRecordinstances contained in the returnedRecordsinstance; there may be moreRecordinstances which are not contained in theRecordsinstance in case theRecordsinstance's size is that of the specified limit.- Returns:
- A
Recordsinstance containing all availableRecordinstances being logged matching the given criteria and restrictions.
-
findLogs
Retrieves all availableRecordinstances being logged matching the given criteria and restrictions.- Specified by:
findLogsin interfaceQueryLogger<L extends QueryLogger<T>>- Parameters:
aCriteria- TheCriteriato be applied to theRecordinstancesaLimit- The maximumRecordinstances contained in the returnedRecordsinstance; there may be moreRecordinstances which are not contained in theRecordsinstance in case theRecordsinstance's size is that of the specified limit.- Returns:
- A
Recordsinstance containing all availableRecordinstances being logged matching the given criteria and restrictions. - Throws:
BadCriteriaException- thrown in case of problems related to someCriteria.
-
findLogs
Retrieves all availableRecordinstances being logged matching the given criteria and restrictions.- Specified by:
findLogsin interfaceQueryLogger<L extends QueryLogger<T>>- Parameters:
aCriteria- TheCriteriato be applied to theRecordinstancesaHeader- TheHeaderused to restrict the "columns" (key/value entries) in the retrievedRecordinstances (provided by theRecordsinstance).- Returns:
- A
Recordsinstance containing all availableRecordinstances being logged matching the given criteria and restrictions. - Throws:
BadCriteriaException- thrown in case of problems related to someCriteria.
-
findLogs
public Records<T> findLogs(Criteria aCriteria, Header<T> aHeader, int aLimit) throws BadCriteriaException Retrieves all availableRecordinstances being logged matching the given criteria and restrictions.- Specified by:
findLogsin interfaceQueryLogger<L extends QueryLogger<T>>- Parameters:
aCriteria- TheCriteriato be applied to theRecordinstancesaHeader- TheHeaderused to restrict the "columns" (key/value entries) in the retrievedRecordinstances (provided by theRecordsinstance).aLimit- The maximumRecordinstances contained in the returnedRecordsinstance; there may be moreRecordinstances which are not contained in theRecordsinstance in case theRecordsinstance's size is that of the specified limit.- Returns:
- A
Recordsinstance containing all availableRecordinstances being logged matching the given criteria and restrictions. - Throws:
BadCriteriaException- thrown in case of problems related to someCriteria.
-
log
-
getLoggers
-