Class RuntimeLoggerFactorySingleton
java.lang.Object
org.refcodes.logger.RuntimeLoggerFactoryImpl
org.refcodes.logger.RuntimeLoggerFactorySingleton
- All Implemented Interfaces:
org.refcodes.factory.Factory<RuntimeLogger>,org.refcodes.factory.LookupFactory<RuntimeLogger,,String> org.refcodes.factory.TypeFactory<RuntimeLogger>,RuntimeLoggerFactory,org.refcodes.mixin.TypeAccessor<RuntimeLogger>
The singleton of the
RuntimeLoggerFactoryImpl for easy
RuntimeLogger creation. See RuntimeLoggerFactoryImpl on how
to set up your "runtimelogger-config.xml" for your individual-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.mixin.TypeAccessor
org.refcodes.mixin.TypeAccessor.TypeBuilder<T,B extends org.refcodes.mixin.TypeAccessor.TypeBuilder<T, B>>, org.refcodes.mixin.TypeAccessor.TypeMutator<T>, org.refcodes.mixin.TypeAccessor.TypeProperty<T> -
Constructor Summary
ConstructorsModifierConstructorDescriptionprotectedInstantiates a new runtime logger factory singleton. -
Method Summary
Modifier and TypeMethodDescriptionstatic voidInitializes theRuntimeLoggerfunctionality, e.g. binds the JUL framework the theRuntimeLoggertoolkit.static RuntimeLoggerConvenience method actually delegating the call to the instance returned bygetInstance().static RuntimeLoggercreateRuntimeLogger(String aIdentifier) Convenience method actually delegating the call to the instance returned bygetInstance().createRuntimeLogger(String aIdentifier, Map<String, String> aProperties) Convenience method actually delegating the call to the instance returned bygetInstance().static RuntimeLoggercreateRuntimeLogger(Map<String, String> aProperties) Convenience method actually delegating the call to the instance returned bygetInstance().static RuntimeLoggerFactoryReturns the singleton's instance as fabricated by thisRuntimeLoggerFactorySingleton.Methods inherited from class org.refcodes.logger.RuntimeLoggerFactoryImpl
create, create, create, create, fromConfigurationFileMethods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, waitMethods inherited from interface org.refcodes.factory.TypeFactory
getType
-
Constructor Details
-
RuntimeLoggerFactorySingleton
protected RuntimeLoggerFactorySingleton()Instantiates a new runtime logger factory singleton.
-
-
Method Details
-
getInstance
Returns the singleton's instance as fabricated by thisRuntimeLoggerFactorySingleton.- Returns:
- The
RuntimeLoggerFactorysingleton's instance.
-
createRuntimeLogger
Convenience method actually delegating the call to the instance returned bygetInstance(). See alsoFactory.create().- Returns:
- the runtime logger
-
createRuntimeLogger
Convenience method actually delegating the call to the instance returned bygetInstance(). See alsoTypeFactory.create(Map).- Parameters:
aProperties- the properties- Returns:
- the runtime logger
-
createRuntimeLogger
Convenience method actually delegating the call to the instance returned bygetInstance(). See alsoTypeFactory.create(Map).- Parameters:
aIdentifier- the identifier- Returns:
- the runtime logger
-
createRuntimeLogger
Convenience method actually delegating the call to the instance returned bygetInstance(). See alsoLookupFactory.create(Object, Map).- Parameters:
aIdentifier- the identifieraProperties- the properties- Returns:
- the runtime logger
-
bindJavaUtilLogging
public static void bindJavaUtilLogging()Initializes theRuntimeLoggerfunctionality, e.g. binds the JUL framework the theRuntimeLoggertoolkit.
-