Class RuntimeLoggerFactorySingleton

java.lang.Object
org.refcodes.logger.DefaultRuntimeLoggerFactory
org.refcodes.logger.RuntimeLoggerFactorySingleton
All Implemented Interfaces:
org.refcodes.factory.Factory<RuntimeLogger>, org.refcodes.factory.LookupFactory<RuntimeLogger,String>, org.refcodes.factory.TypeFactory<RuntimeLogger>, RuntimeLoggerFactory, org.refcodes.mixin.TypeAccessor<RuntimeLogger>

public class RuntimeLoggerFactorySingleton extends DefaultRuntimeLoggerFactory
The singleton of the DefaultRuntimeLoggerFactory for easy RuntimeLogger creation. See DefaultRuntimeLoggerFactory on how to set up your "runtimelogger-config.xml" for your individual
  • Nested Class Summary

    Nested classes/interfaces inherited from interface org.refcodes.factory.Factory

    org.refcodes.factory.Factory.ConfigurableFactory<T,OPTS>

    Nested classes/interfaces inherited from interface org.refcodes.factory.LookupFactory

    org.refcodes.factory.LookupFactory.ConfigurableLookupFactory<T,TID,OPTS>

    Nested classes/interfaces inherited from interface org.refcodes.mixin.TypeAccessor

    org.refcodes.mixin.TypeAccessor.TypeBuilder<T,B extends org.refcodes.mixin.TypeAccessor.TypeBuilder<T,B>>, org.refcodes.mixin.TypeAccessor.TypeMutator<T>, org.refcodes.mixin.TypeAccessor.TypeProperty<T>

    Nested classes/interfaces inherited from interface org.refcodes.factory.TypeFactory

    org.refcodes.factory.TypeFactory.ConfigurableTypeFactory<T,OPTS>
  • Constructor Summary

    Constructors
    Modifier
    Constructor
    Description
    protected
    Instantiates a new runtime logger factory singleton.
  • Method Summary

    Modifier and Type
    Method
    Description
    static void
    Initializes the RuntimeLogger functionality, e.g. binds the JUL framework the the RuntimeLogger toolkit.
    Convenience method actually delegating the call to the instance returned by getInstance().
    Convenience method actually delegating the call to the instance returned by getInstance().
    Returns the singleton's instance as fabricated by this RuntimeLoggerFactorySingleton.

    Methods inherited from class org.refcodes.logger.DefaultRuntimeLoggerFactory

    create, create, fromConfigurationFile

    Methods inherited from class java.lang.Object

    clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait

    Methods inherited from interface org.refcodes.factory.TypeFactory

    getType
  • Constructor Details

    • RuntimeLoggerFactorySingleton

      protected RuntimeLoggerFactorySingleton()
      Instantiates a new runtime logger factory singleton.
  • Method Details