Uses of Interface
org.refcodes.logger.QueryLogger
-
Uses of QueryLogger in org.refcodes.logger
Subinterfaces of QueryLogger in org.refcodes.loggerModifier and TypeInterfaceDescriptioninterfaceTrimLogger<T>TheTrimLoggerextends theQueryLoggerwith the functionality to removeRecordinstances previously being logged by providing the accordingCriteria.Classes in org.refcodes.logger that implement QueryLoggerModifier and TypeClassDescriptionclassPartedQueryLogger<T,P extends T> ThePartedQueryLoggeris a ready to use implementation of a partedQueryLoggerextending theAbstractPartedQueryLogger.classPartedTrimLogger<T,P extends T> ThePartedTrimLoggeris a ready to use implementation of a partedTrimLoggerextending theAbstractPartedTrimLogger.classTheQueryLoggerCompositeis a ready to use implementation of a compositeQueryLoggerextending theAbstractQueryLoggerComposite.classTheTrimLoggerCompositeis a ready to use implementation of a compositeTrimLoggerextending theAbstractTrimLoggerComposite.Subclasses with type arguments of type QueryLogger in org.refcodes.loggerModifier and TypeClassDescriptionclassPartedQueryLogger<T,P extends T> ThePartedQueryLoggeris a ready to use implementation of a partedQueryLoggerextending theAbstractPartedQueryLogger.classTheQueryLoggerCompositeis a ready to use implementation of a compositeQueryLoggerextending theAbstractQueryLoggerComposite.classImplementation of theAbstractLoggerFactoryCompositecreating compositeQueryLoggerinstances.Methods in org.refcodes.logger with type parameters of type QueryLoggerModifier and TypeMethodDescriptionstatic <L extends QueryLogger<T>,T>
org.refcodes.tabular.Records<T> LoggerUtility.findLogs(org.refcodes.criteria.Criteria aCriteria, org.refcodes.tabular.Header<T> aHeader, int aLimit, Collection<L> aLoggers, org.refcodes.controlflow.InvocationStrategy aRecordServeStrategy) Functionality to query multipleQueryLoggerinstances with the same query and returning a single compositeRecordsinstance containing allRecordinstances returned by the queriedQueryLoggerinstances (multi-threaded).Methods in org.refcodes.logger that return QueryLoggerModifier and TypeMethodDescriptionprotected QueryLogger<T> QueryLoggerFactoryComposite.createCompositeLogger(QueryLogger<T>[] aLoggers) To be implemented by sub-classes, this method creates aLoggerComposite(or its sub-classes) from the providedLoggerinstances (or its sub-types).Methods in org.refcodes.logger with parameters of type QueryLoggerModifier and TypeMethodDescriptionprotected QueryLogger<T> QueryLoggerFactoryComposite.createCompositeLogger(QueryLogger<T>[] aLoggers) To be implemented by sub-classes, this method creates aLoggerComposite(or its sub-classes) from the providedLoggerinstances (or its sub-types).Constructors in org.refcodes.logger with parameters of type QueryLoggerModifierConstructorDescriptionQueryLoggerComposite(org.refcodes.controlflow.ExecutionStrategy aComponentExecutionStrategy, QueryLogger<T>... aLoggers) Similar to theQueryLoggerComposite(QueryLogger...)with the additional option of determining the execution strategy of the state change request calls for the encapsulatedQueryLoggerinstances (as ofComponentComposite).QueryLoggerComposite(QueryLogger<T>... aLoggers) Instantiates a newQueryLoggerCompositecomposed of the providedQueryLoggerinstances.Constructor parameters in org.refcodes.logger with type arguments of type QueryLoggerModifierConstructorDescriptionPartedQueryLogger(org.refcodes.controlflow.ExecutionStrategy aComponentExecutionStrategy, org.refcodes.tabular.Column<P> aPartitionColumn, String aDefaultLoggerName, LoggerFactory<QueryLogger<T>> aLoggerFactory, boolean isPartitionAutoInitialize) Similar to thePartedQueryLogger(Column, LoggerFactory, boolean)with the additional option of determining the execution strategy of the state change request calls for the encapsulatedQueryLoggerinstances (as ofComponentComposite).PartedQueryLogger(org.refcodes.controlflow.ExecutionStrategy aComponentExecutionStrategy, org.refcodes.tabular.Column<P> aPartitionColumn, LoggerFactory<QueryLogger<T>> aLoggerFactory, boolean isPartitionAutoInitialize) Similar to thePartedQueryLogger(Column, LoggerFactory, boolean)with the additional option of determining the execution strategy of the state change request calls for the encapsulatedQueryLoggerinstances (as ofComponentComposite).PartedQueryLogger(org.refcodes.tabular.Column<P> aPartitionColumn, String aDefaultLoggerName, LoggerFactory<QueryLogger<T>> aLoggerFactory, boolean isPartitionAutoInitialize) Instantiates a newPartedQueryLoggerwith the according parameters.PartedQueryLogger(org.refcodes.tabular.Column<P> aPartitionColumn, LoggerFactory<QueryLogger<T>> aLoggerFactory, boolean isPartitionAutoInitialize) Instantiates a newPartedQueryLoggerwith the according parameters.QueryLoggerFactoryComposite(LoggerFactory<QueryLogger<T>> aLoggerFactory, int aNumEndpoints) Instantiates a new composite query logger factory impl.